@@ -1,7 +1,7 @@
 #
 # This file is part of Config-Model-Itself
 #
-# This software is Copyright (c) 2007-2018 by Dominique Dumont.
+# This software is Copyright (c) 2007-2019 by Dominique Dumont.
 #
 # This is free software, licensed under:
 #
@@ -25,6 +25,9 @@
 #    along with Config-Model-Itself; if not, write to the Free Software
 #    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 
+use strict;
+use warnings;
+
 my @warp_in_string_like_parameter = (
     warp => {
         follow => {
@@ -85,7 +88,7 @@ my %assert_payload = (
     @warp_in_leaf_parameter,
 );
 
-[
+return [
     [
         name    => 'Itself::CommonElement::WarnIfMatch',
         element => [
